@@ -3,7 +3,7 @@ import time
 
 from .base import BaseAction
 from ..relation import EndpointPair
-from ..utils import _parse_constraints, yaml_dump
+from ..utils import parse_constraints, yaml_dump
 
 
 class Diff(BaseAction):
@@ -111,7 +111,8 @@ class Diff(BaseAction):
         for cs in env_svcs.intersection(dep_svcs):
             d_s = self.deployment.get_service(cs).svc_data
             e_s = self.env_state['services'][cs]
-            mod = self._diff_service(e_s, d_s)
+            mod = self._diff_service(e_s, d_s,
+                                     self.deployment.get_charm_for(cs))
             if not mod:
                 continue
             if not 'modified' in delta:
@@ -119,10 +120,10 @@ class Diff(BaseAction):
             delta['modified'][cs] = mod
         return delta
 
-    def _diff_service(self, e_s, d_s):
+    def _diff_service(self, e_s, d_s, charm):
         mod = {}
         if 'constraints' in d_s:
-            d_sc = _parse_constraints(d_s['constraints'])
+            d_sc = parse_constraints(d_s['constraints'])
             if d_sc != e_s['constraints']:
                 mod['constraints'] = e_s['constraints']
         for k, v in d_s.get('options', {}).items():
@@ -133,8 +134,9 @@ class Diff(BaseAction):
             e_v = e_s['options'].get(k, {}).get('value')
             if e_v != v:
                 mod['config'] = {k: e_v}
-        if e_s['unit_count'] != d_s.get('num_units', 1):
-            mod['num_units'] = e_s['unit_count'] - d_s['num_units']
+        if not charm or not charm.is_subordinate():
+            if e_s['unit_count'] != d_s.get('num_units', 1):
+                mod['num_units'] = e_s['unit_count'] - d_s.get('num_units', 1)
         return mod
 
     def run(self):
