@@ -103,6 +103,10 @@ class Importer(BaseAction):
                 num_units,
                 self.deployment.get_unit_placement(svc, 0, env_status))
 
+            if svc.annotations:
+                self.log.debug(" Setting annotations")
+                self.env.set_annotation(svc.name, svc.annotations)
+
             if svc.expose:
                 self.log.info(" Exposing service %r" % svc.name)
                 self.env.expose(svc.name)
