@@ -69,8 +69,9 @@ class ConfigStack(object):
             d = self._yaml_load(fp)
             data = dict_merge(data, d)
         self.data = data
-        if 'include-config' in self.data:
-            self.data.pop('include-config')
+        for k in ['include-config', 'include-configs']:
+            if k in self.data:
+                self.data.pop(k)
         self.include_dirs = include_dirs
 
     def _inherits(self, d):
@@ -94,11 +95,19 @@ class ConfigStack(object):
     def _includes(self, config_file):
         files = [config_file]
         d = self._yaml_load(config_file)
-        if 'include-config' in d:
-            inc_f = d['include-config']
-            if not isabs(inc_f):
-                inc_f = join(dirname(config_file), inc_f)
-            files.extend(self._includes(inc_f))
+
+        incs = d.get('include-configs') or d.get('include-config')
+        if isinstance(incs, basestring):
+            inc_fs = [incs]
+        else:
+            inc_fs = incs
+
+        if inc_fs:
+            for inc_f in inc_fs:
+                if not isabs(inc_f):
+                    inc_f = join(dirname(config_file), inc_f)
+                files.extend(self._includes(inc_f))
+
         return files
 
     def _resolve_included(self):
