@@ -58,7 +58,13 @@ class GoEnvironment(BaseEnvironment):
         return self.client.get_config(svc_name)
 
     def get_constraints(self, svc_name):
-        return self.client.get_constraints(svc_name)
+        try:
+            return self.client.get_constraints(svc_name)
+        except EnvError, e:
+            if 'constraints do not apply to subordinate services' in str(e):
+                return None
+            else:
+                raise e
 
     def get_cli_status(self):
         status = super(GoEnvironment, self).get_cli_status()
