@@ -44,14 +44,16 @@ class GUIEnvironment(GoEnvironment):
         self.client = None
 
     def deploy(
-            self, name, charm_url, config=None, constraints=None, num_units=1,
-            *args, **kwargs):
+            self, name, charm_url, repo=None, config=None, constraints=None,
+            num_units=1, force_machine=None):
         """Deploy a service using the API.
 
         Using the API in place of the command line introduces some limitations:
-          - it is not possible to use a local charm/repository;
-          - it is not possible to deploy to a specific machine.
+          - it is not possible to use a local charm/repository.
+
+        The repo argument is ignored but listed since the Importer always
+        passes the value as a positional argument.
         """
         self.client.deploy(
             name, charm_url, config=config, constraints=constraints,
-            num_units=num_units)
+            num_units=num_units, machine_spec=force_machine)
