@@ -38,7 +38,7 @@ class Service(object):
             value = self.svc_data.get('force-machine')
         if value is not None and not isinstance(value, list):
             value = [value]
-        return value or []
+        return value and map(str, value) or []
 
     @property
     def expose(self):
