@@ -41,11 +41,11 @@ class TestGUIEnvironment(unittest.TestCase):
         self.env.connect()
         config = {'foo': 'bar'}
         constraints = {'cpu': 4}
-        # Deploy a service: the last two arguments (force_machine and repo) are
-        # ignored.
+        # Deploy a service: the repo argument is ignored.
         self.env.deploy(
-            'myservice', 'cs:precise/service-42', config=config,
-            constraints=constraints, num_units=2, force_machine=1, repo='/tmp')
+            'myservice', 'cs:precise/service-42', repo='/my/repo/',
+            config=config, constraints=constraints, num_units=2,
+            force_machine=1)
         mock_client().deploy.assert_called_once_with(
             'myservice', 'cs:precise/service-42', config=config,
-            constraints=constraints, num_units=2)
+            constraints=constraints, num_units=2, machine_spec=1)
